@@ -383,12 +383,12 @@ assign_grids <- function(ROW, COL, width, height, polar = FALSE) {
 }
 
 # Compute grid lines and text labels for frame_calendar()
-gen_reference <- function(grids, dir = "h", ...) {
+gen_reference <- function(grids, margin, dir = "h", week_start = 1, ...) {
   dir <- match.arg(dir, c("h", "v"))
   UseMethod("gen_reference")
 }
 
-gen_reference.daily <- function(grids, dir = "h", ...) {
+gen_reference.daily <- function(grids, margin, dir = "h", week_start = 1, ...) {
   # day breaks
   minor_breaks <- gen_day_breaks(grids)
   min_width <- min_diff(minor_breaks$x)
@@ -430,7 +430,7 @@ gen_reference.daily <- function(grids, dir = "h", ...) {
   list(breaks = NULL, minor_breaks = minor_breaks, label = mtext, text = dtext)
 }
 
-gen_reference.weekly <- function(grids, dir = "h", ...) {
+gen_reference.weekly <- function(grids, margin, dir = "h", week_start = 1, ...) {
   # day breaks
   minor_breaks <- gen_day_breaks(grids)
   min_width <- min_diff(minor_breaks$x)
